# JskToolBox

The project contains sets of base classes for various operations.

## AttribTool

The project contains base classes that limit the possibility of adding new attributes without their prior declaration inside classes inheriting from them or their objects.

[AttribTool Readme](https://github.com/Szumak75/JskToolBox/blob/1.0.15/docs/AttribTool.md)

## ConfigTool

The project contains classes that enable common operations on configuration files.

[ConfigTool Readme](https://github.com/Szumak75/JskToolBox/blob/1.0.15/docs/ConfigTool.md)

## DateTool

The project contains classes for various date/time operations.

[DateTool Readme](https://github.com/Szumak75/JskToolBox/blob/1.0.15/docs/DateTool.md)

## LogsTool

The project contains several classes that create a logging subsystem for the designed solutions.

[LogsTool Readme](https://github.com/Szumak75/JskToolBox/blob/1.0.15/docs/LogsTool.md)

## NetAddressTool

The project contains sets of base classes for operations on IPv4 and IPv6 addresses.

[NetAddressTool Readme](https://github.com/Szumak75/JskToolBox/blob/1.0.15/docs/NetAddressTool.md)

## RaiseTool

The project contains small class for formatting thrown exception messages.

[RaiseTool Readme](https://github.com/Szumak75/JskToolBox/blob/1.0.15/docs/RaiseTool.md)

## StringTool

The project contains sets of classes for various operations on string.

[StringTool Readme](https://github.com/Szumak75/JskToolBox/blob/1.0.15/docs/StringTool.md)

## TkTool

The project contains sets of classes for tkinter framework.

[TkTool Readme](https://github.com/Szumak75/JskToolBox/blob/1.0.15/docs/TkTool.md)
